import matplotlib.pyplot as plt
import numpy as np
import matplotlib as mpl

N_T = 10
N_N = 7
T_min, T_max = 1e-2, 0.2

t2s_sym= np.loadtxt(f"Data/Decoherence/t2N8_sym_T{T_min}{T_max}")
t2s_no_relax = np.loadtxt(f"Data/Decoherence/t2N8_no_dephasing_T{T_min}{T_max}")
t2s_sym_high= np.loadtxt(f"Data/Decoherence/t2N8_sym")
t2s_no_relax_high = np.loadtxt(f"Data/Decoherence/t2N8_no_dephasing")

# +
#T2 plot
font = {"size": 18}

plt.rc("font", **font)

Ts = np.linspace(T_min, T_max, N_T)
colors = ["#5790fc", "#f89c20", "#e42536", "#964a8b", "#9c9ca1", "#7a21dd"]

norm = mpl.colors.Normalize(vmin=T_min-0.1, vmax=T_max+0.1)
cmap = mpl.cm.ScalarMappable(norm=norm, cmap="gist_heat_r")

fig, ax = plt.subplots(1, 1)

labels = []
for i in range(0,10,2):
    ax.plot(
        range(2, 9),
        t2s_sym[:, i],
        ".",
        c=cmap.to_rgba(Ts[i]),
        markersize=15,
    )
    ax.plot(
        range(2, 9),
        t2s_no_relax[:, i],
        ".",
        c=cmap.to_rgba(Ts[i]),
        markersize=15,
        fillstyle="none",
    )
    labels.append(rf"$T$ = {np.round(Ts[i],2)} K")
lines = ax.get_lines()
ax.set_xlim([1, 9])
ax.set_xticks(np.arange(2, 9))
ax.set_xlabel("Chain length")
ax.set_ylabel(r"$T_2$ (ns)")
first_legend = ax.legend([lines[i] for i in range(0, 9, 2)], labels, loc=[1.05, 0.4])
second_legend = ax.legend(
    [lines[i] for i in range(7, 9)],
    ["inelastic only", "elastic and inelastic"],
    loc=(1.05, 0.1),
)
ax.add_artist(first_legend)

#plt.savefig("Images/Decoherence_N8_full_V2.svg", bbox_inches="tight")
plt.show()

# +
#ratio plot
font = {"size": 14}

plt.rc("font", **font)

T_min, T_max = 1e-2, 0.75
Ts_high = np.linspace(T_min, T_max, N_T)
norm = mpl.colors.Normalize(vmin=0, vmax=10)
cmap = mpl.cm.ScalarMappable(norm=norm, cmap="gist_heat_r")
for i, N in enumerate(Ns):
    total_t2_sym = np.hstack([t2s_sym[i, :], t2s_sym_high[i, 3:]])
    total_t2_no_relax = np.hstack([t2s_no_relax[i, :], t2s_no_relax_high[i, 3:]])
    Ts_total = np.hstack([Ts, Ts_high[3:]])
    plt.plot(Ts_total, total_t2_no_relax/total_t2_sym, markersize=10, c=cmap.to_rgba(Ns[i]), label=rf"$N$ = {Ns[i]}")
    plt.ylabel(r"$T_2^{\text{inel}}$ / $T_2$")
    plt.xlabel(r"$T$ (K)")
plt.legend(loc=[1.05, 0.4])
plt.show()
